ShowPopupOnClickWidget | django_cradmin API Document

    import ShowPopupOnClickWidget from 'django_cradmin/scripts/django_cradmin/widgets/ShowPopupOnClickWidget.js'

public class | source

# ShowPopupOnClickWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → ShowPopupOnClickWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Member Summary

Public Members
public | logger: * |

## Method Summary

Public Methods
public | destroy() |
public | getDefaultConfig(): * |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Members

### public logger: * source

## Public Methods

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*